

.. |docs| image:: https://readthedocs.org/projects/imgmarker/badge/?version=latest
    :target: https://imgmarker.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. |github| image:: https://img.shields.io/badge/GitHub-Image%20Marker-red
   :target: https://github.com/andikisare/imgmarker

.. |pyqt| image:: https://img.shields.io/badge/powered%20by-PyQt-blue.svg?style=flat
    :target: https://www.riverbankcomputing.com/static/Docs/PyQt6/

.. |icon| image:: https://raw.githubusercontent.com/andikisare/imgmarker/main/imgmarker/icon.ico
    :width: 40

.. |license| image:: https://img.shields.io/github/license/andikisare/imgmarker
    :target: https://github.com/andikisare/imgmarker/blob/main/LICENSE

.. |CI| image:: https://github.com/andikisare/imgmarker/actions/workflows/python-app.yml/badge.svg
    :target: https://github.com/andikisare/imgmarker/actions/workflows/python-app.yml

.. |JOSS| image:: https://joss.theoj.org/papers/21a640a3fd4e2ad1815891a61af4a21b/status.svg
    :target: https://joss.theoj.org/papers/21a640a3fd4e2ad1815891a61af4a21b

|icon| Image Marker
#####################

|github| |license| |pyqt| |docs| |CI| |JOSS|

Image Marker is a tool for marking, categorizing, and annotating TIFF, FITS, PNG, and JPEG files.
Image Marker does not modify the image itself, it only displays it and creates text files containing 
the information that you mark. Image Marker uses `PyQt <https://pypi.org/project/PyQt6/>`_ 
to build the GUI application, `Pillow <https://pypi.org/project/pillow/>`_ to handle images, and `astropy <https://www.astropy.org/>`_ to load FITS data and convert coordinates.
For tutorials, instructions, and details on functionality, visit the `online documentation <https://imgmarker.readthedocs.io/en/latest/>`_.

Citation
*********************

(coming soon)

    
